@@ -17,4 +17,7 @@
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
+
+from .core import *
+from . import motor
